Permute the entries of the named axes in a writable leaf Daf (or a set of leaf Dafs sharing those axes), rewriting all data that depends on them. Not valid for chain or view Dafs. See the Julia documentation for details.
Permute the entries of the named axes in a writable leaf Daf (or a set of leaf Dafs sharing those axes), rewriting all data that depends on them. Not valid for chain or view Dafs. See the Julia documentation for details.